@@ -124,7 +124,7 @@ def plainSupervised(path,pathUnlabelled,learn,th):
     if not os.path.exists(newPath):
         shutil.copytree(path, newPath)
     else:
-        raise NamedError("The path "+newPath+" already exists")
+        raise Exception("The path "+newPath+" already exists")
     for image in images:
         pn=learn.predict(image)
         if pn[2][pn[2].argmax()]>th:
@@ -209,7 +209,7 @@ def create_shufflenet(num_classes):
     elif callable(cut):
         body= cut(body)
     else:
-        raise NamedError("cut must be either integer or function")
+        raise Exception("cut must be either integer or function")
 
     nf = num_features_model(nn.Sequential(*body.children())) * (2)
     head = create_head(nf, num_classes)
@@ -229,7 +229,7 @@ def create_squeezenet(num_classes):
     elif callable(cut):
         body= cut(body)
     else:
-        raise NamedError("cut must be either integer or function")
+        raise Exception("cut must be either integer or function")
     nf = num_features_model(nn.Sequential(*body.children())) * (2)
     head = create_head(nf, num_classes)
     model = nn.Sequential(body, head)
